@@ -5,8 +5,8 @@ from lbworkflow import settings
 
 
 def safe_eval(source, globals, *args, **kwargs):
-    globals['Q'] = Q
+    globals["Q"] = Q
     for s in settings.EVAL_FUNCS:
         globals[s[0]] = as_callable(s[1])
-    source = source.replace('import', '')
+    source = source.replace("import", "")
     return eval(source, globals, *args, **kwargs)
