@@ -4,7 +4,7 @@ from .models import SimpleWorkFlow
 
 
 class SimpleWorkFlowAdmin(admin.ModelAdmin):
-    list_display = ('summary', 'content')
+    list_display = ("summary", "content")
 
 
 admin.site.register(SimpleWorkFlow, SimpleWorkFlowAdmin)
