@@ -1,6 +1,4 @@
-from lbworkflow.views.generics import CreateView
-from lbworkflow.views.generics import UpdateView
-from lbworkflow.views.generics import WFListView
+from lbworkflow.views.generics import CreateView, UpdateView, WFListView
 
 from .forms import SimpleWorkFlowForm
 from .models import SimpleWorkFlow
@@ -8,16 +6,19 @@ from .models import SimpleWorkFlow
 
 class SimpleWorkFlowCreateView(CreateView):
     form_classes = {
-        'form': SimpleWorkFlowForm,
+        "form": SimpleWorkFlowForm,
     }
 
+    def get_initial(self, form_class_key):
+        return {"content": self.process.ext_data.get("template", "")}
+
 
 new = SimpleWorkFlowCreateView.as_view()
 
 
 class SimpleWorkFlowUpdateView(UpdateView):
     form_classes = {
-        'form': SimpleWorkFlowForm,
+        "form": SimpleWorkFlowForm,
     }
 
 
@@ -25,19 +26,23 @@ edit = SimpleWorkFlowUpdateView.as_view()
 
 
 class SimpleWorkFlowListView(WFListView):
-    wf_code = 'simplewf'
+    wf_code = "simplewf"
     model = SimpleWorkFlow
-    excel_file_name = 'simplewf'
+    excel_file_name = "simplewf"
     excel_titles = [
-        'Created on', 'Created by',
-        'Summary', 'Content',
-        'Status',
+        "Created on",
+        "Created by",
+        "Summary",
+        "Content",
+        "Status",
     ]
 
     def get_excel_data(self, o):
         return [
-            o.created_by.username, o.created_on,
-            o.summary, o.content,
+            o.created_by.username,
+            o.created_on,
+            o.summary,
+            o.content,
             o.pinstance.cur_node.name,
         ]
 
