@@ -4,9 +4,7 @@ from .forms import HRForm
 
 
 class CustomizedTransitionView(ExecuteTransitionView):
-    form_classes = {
-        'form': HRForm
-    }
+    form_classes = {"form": HRForm}
 
 
 c = CustomizedTransitionView.as_view()
